@@ -2,6 +2,7 @@ from calendar import HTMLCalendar, day_abbr
 from datetime import date, datetime
 from itertools import groupby
 
+from django.template.loader import render_to_string
 from django.utils.formats import date_format
 from django.utils.translation import gettext as _
 
@@ -24,23 +25,20 @@ class ShiftCalendar(HTMLCalendar):
         return f'<tr><th colspan="7" class="month">{date_format(dt, format="b Y")}</th></tr>'
 
     def formatweekday(self, day):
-        return f'<th class="{self.cssclasses[day]}">{_(day_abbr[day])}</th>'
+        return f'<th class="text-center {self.cssclasses[day]}">{_(day_abbr[day])}</th>'
 
     def formatday(self, day, weekday):
         if day != 0:
             cssclass = self.cssclasses[weekday]
-            if date.today() == date(self.year, self.month, day):
-                cssclass += " calendar-today"
+            today = date.today() == date(self.year, self.month, day)
             if day in self.shifts:
                 cssclass += " filled"
-                body = ["<br />"]
-                for shift in self.shifts[day]:
-                    body.append(f'<a href="{shift.event.get_absolute_url()}">')
-                    body.append(shift.event.title)
-                    body.append("</a><br />")
-                return self.day_cell(cssclass, f"{day} {''.join(body)}")
-            return self.day_cell(cssclass, day)
+            content = render_to_string(
+                "core/fragments/calendar_day.html",
+                {"day": day, "shifts": self.shifts.get(day, None), "today": today},
+            )
+            return self.day_cell(cssclass, content)
         return self.day_cell("noday", "&nbsp;")
 
     def day_cell(self, cssclass, body):
-        return f'<td class="calendar-row-height p-1 break-word {cssclass}">{body}</td>'
+        return f'<td class="calendar-row-height p-0 pe-1 p-lg-1 {cssclass}">{body}</td>'
