@@ -128,7 +128,9 @@ class Event(Model):
     def get_absolute_url(self):
         from django.urls import reverse
 
-        return reverse("core:event_detail", kwargs=dict(pk=self.id, slug=self.get_canonical_slug()))
+        return reverse(
+            "core:event_detail", kwargs={"pk": self.id, "slug": self.get_canonical_slug()}
+        )
 
     def activate(self):
         if not self.active:
